@@ -4,6 +4,7 @@ from vscodedebugvisualizer.visualizer.PandasVisualizer import PandasVisualizer
 from vscodedebugvisualizer.visualizer.PrimitiveVisualizer import PrimitiveVisualizer
 from vscodedebugvisualizer.visualizer.PyTorchVisualizer import PyTorchVisualizer
 from vscodedebugvisualizer.visualizer.TensorflowVisualizer import TensorflowVisualizer
+from vscodedebugvisualizer.visualizer.DirectVisualizer import DirectVisualizer
 
 
 class Visualize:
@@ -14,9 +15,7 @@ class Visualize:
 
     def visualize(self, data):
         for v in self.visualizers:
-            print("Check type for %s found" % v)
             if v.checkType(data):
-                print("Visualizer %s found" % v)
                 return v.visualize(data)
         print("No Visualizer found for specified Type: %s" % type(data))
         return None
@@ -31,6 +30,7 @@ class Visualizer:
 
 
 globalVisualizationFactory = Visualize()
+globalVisualizationFactory.addVisualizer(DirectVisualizer())
 globalVisualizationFactory.addVisualizer(PrimitiveVisualizer())
 globalVisualizationFactory.addVisualizer(ListVisualizer())
 globalVisualizationFactory.addVisualizer(NumpyVisualizer())
